@@ -343,12 +343,17 @@ void placeMapWidget::wheelEvent(QWheelEvent *e)
 	if ( e->modifiers() == Qt::NoModifier ) QGraphicsView::wheelEvent(e);
 	else if ( e->modifiers()  == Qt::ShiftModifier )
 	{
-		QWheelEvent reorientedEvent(e->pos(), e->delta(), e->buttons(), Qt::NoModifier, Qt::Orientation(3 -int(e->orientation())));
+		// Scroll horizontally by swapping x and y for the delta
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		QWheelEvent reorientedEvent(e->position(), e->globalPosition(), e->pixelDelta().transposed(), -e->angleDelta().transposed(), e->buttons(), Qt::NoModifier, e->phase(), e->inverted(), e->source(), e->pointingDevice());
+#else
+		QWheelEvent reorientedEvent(e->position(), e->globalPosition(), e->pixelDelta().transposed(), e->angleDelta().transposed(), e->buttons(), Qt::NoModifier, e->phase(), e->inverted(), e->source());
+#endif
 		QGraphicsView::wheelEvent(&reorientedEvent);
 	}
 	else if ( e->modifiers()  == Qt::ControlModifier )
 	{
-		int delta = e->delta();
+		int delta = e->angleDelta().y();
 		if ( delta != 0 )
 		{
 			const qreal rescale = pow(2, qreal(delta/120)/2.0);
@@ -357,7 +362,11 @@ void placeMapWidget::wheelEvent(QWheelEvent *e)
 	}
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void placeMapWidget::enterEvent(QEnterEvent*)
+#else
 void placeMapWidget::enterEvent(QEvent*)
+#endif
 {
 	if (p_currentDivisionItem)
 	{
